From 1bbd0e01e3dc3f70bd2d86cd6e1669422bfd6e66 Mon Sep 17 00:00:00 2001
From: Luke Shumaker <lukeshu@sbcglobal.net>
Date: Sun, 18 Dec 2016 15:01:40 -0500
Subject: Godoc comments.

---
 inotify/bits.go | 9 ++++++---
 1 file changed, 6 insertions(+), 3 deletions(-)

(limited to 'inotify')

diff --git a/inotify/bits.go b/inotify/bits.go
index fa44f9b..a982e42 100644
--- a/inotify/bits.go
+++ b/inotify/bits.go
@@ -1,4 +1,4 @@
-// Copyright (C) 2015 Luke Shumaker
+// Copyright (C) 2015-2016 Luke Shumaker
 //
 // Many of the comments in this file are taken from the GNU libc
 // header file <sys/inotify.h>
@@ -28,8 +28,11 @@ const (
 	IN_NONBLOCK int = 00004000
 )
 
-type file int // File Descriptor
-type Wd int   // Watch Descriptor
+// inFd is a File Descriptor.
+type inFd int
+
+// Wd is a Watch Descriptor.
+type Wd int
 
 type Mask uint32
 
-- 
cgit v1.2.3-2-g168b